@@ -1,13 +1,11 @@
 #!/bin/sh -e
 
 VERSION=$2
-TAR=../plexus-classworlds_$VERSION.orig.tar.gz
-DIR=plexus-classworlds-$VERSION
+TAR=../plexus-classworlds2_$VERSION.orig.tar.gz
+DIR=plexus-classworlds2-$VERSION
 TAG=$(echo "plexus-classworlds-$VERSION" | sed -re's/~(alpha|beta)/-\1-/')
 
 svn export http://svn.codehaus.org/plexus/plexus-classworlds/tags/${TAG}/ $DIR
-rm -f $DIR/classworlds-aj.zip
-rm -rf $DIR/lib
 GZIP=--best tar -c -z -f $TAR --exclude '*.jar' --exclude '*.class' $DIR
 rm -rf $DIR ../$TAG
 
